@@ -2,14 +2,16 @@ from pathlib import Path
 
 import yaml
 
-from . import exceptions
+from . import helpers
 
 
 class Config:
-    FILENAME = 'serverless.yaml'
     VERSION = 'V4'
 
-    def __init__(self):
+    def __init__(self, **kwargs):
+        self.filename = kwargs.get('config_filename')
+        if self.filename is None:
+            self.filename = 'serverless.yaml'
         self.version = None
         self.base_dir = None
         self.cloud_type = None
@@ -20,9 +22,15 @@ class Config:
         self.endpoint_deploy_version = 0
 
     def load(self) -> bool:
-        if not Path(Config.FILENAME).exists():
+        if not Path(self.filename).exists():
+            print(
+                helpers.bcolors.FAIL
+                + 'Config file not found. Please run `init` first.'
+                + helpers.bcolors.ENDC
+            )
             return False
-        with open(Config.FILENAME) as f:
+
+        with open(self.filename) as f:
             data = yaml.safe_load(f)
             self.version = data.get('version', '')
             self.base_dir = data.get('base_dir', '.')
@@ -34,12 +42,17 @@ class Config:
             self.endpoint_deploy_version = int(data.get('endpoints', {}).get('deploy_version', 0))
 
         if str(self.version).strip() != self.VERSION:
-            raise exceptions.ConfigInvalidVersion()
+            print(
+                helpers.bcolors.FAIL
+                + 'Config file is not compatible with this version. Please run `init` again.'
+                + helpers.bcolors.ENDC
+            )
+            return False
 
         return True
 
     def save(self):
-        with open(Config.FILENAME, 'w') as f:
+        with open(self.filename, 'w') as f:
             yaml.dump(self.dict(), f)
 
     def dict(self):
