@@ -4,7 +4,7 @@ from typing import List
 
 import yaml
 
-from . import exceptions, file_contents, helpers, steps
+from . import file_contents, helpers, steps
 from .configs import Config
 
 
@@ -24,7 +24,7 @@ class Runtime:
 
     @property
     def command(self) -> str:
-        return f'gcloud functions deploy --project="{self.config.project}" {self.operation_id} {self.trigger} --runtime {self.runtime} --entry-point="{self.entry_point}" --memory={self.memory} --region="{self.config.region}"'
+        return f'gcloud functions deploy --project="{self.config.project}" {self.operation_id} {self.trigger} --env-vars-file env.yaml --runtime {self.runtime} --entry-point="{self.entry_point}" --memory={self.memory} --region="{self.config.region}"'
 
 
 class Endpoint:
@@ -34,12 +34,34 @@ class Endpoint:
         self.config = kwargs.get('config', None)
         self.runtime_config = None
 
-    def runtime(self, config: Config) -> Runtime:
+    def _load_runtime_config(self, config: Config):
+        if self.runtime_config is not None:
+            return self.runtime_config
         with open(f'{config.base_dir}/endpoints/{self.operation_id}.yaml') as f:
-            runtime_config = yaml.safe_load(f.read())
+            self.runtime_config = yaml.safe_load(f.read())
+        return self.runtime_config
 
+    def runtime(self, config: Config) -> Runtime:
+        runtime_config = self._load_runtime_config(config)
         return Runtime(config, self.operation_id, **runtime_config)
 
+    def _env_secrets(self, config: Config, **kwargs) -> List[dict]:
+        runtime_config = self._load_runtime_config(config)
+        secrets = {x.get('name'): "{{ "+x.get('value')+" }}" for x in runtime_config.get('secrets', [])}
+        return secrets
+
+    def env(self, config: Config, **kwargs) -> str:
+        is_simulate = kwargs.get('is_simulate', False)
+        env = {
+            **self._env_secrets(config, is_simulate=is_simulate),
+            **{
+                'ENV': 'production',
+            }
+        }
+        env = yaml.dump(env, default_flow_style=False)
+        env = env.replace("'{{", "{{").replace("}}'", '}}')
+        return env
+
 
 def endpoint_load(config: Config) -> dict:
     with open(f"{config.base_dir}/api.yaml") as f:
@@ -198,6 +220,14 @@ def cli_main(args, config: Config) -> int:
                 f'{config.base_dir}/endpoints/src',
                 f'{config.base_dir}/build/endpoints/{endpoint.operation_id}/src'
             ),
+            steps.StepCreateFile(
+                f'{config.base_dir}/build/endpoints/{endpoint.operation_id}/env.temp.yaml',
+                endpoint.env(config, is_simulate=args.simulate)
+            ),
+            steps.StepCommand(
+                shlex.split("secrethub inject -i env.temp.yaml -o env.yaml"),
+                work_dir=f'{config.base_dir}/endpoints',
+            ),
             steps.StepCommand(
                 shlex.split(runtime.command),
                 work_dir=f'{config.base_dir}/build/endpoints/{endpoint.operation_id}',
